@@ -1,8 +1,9 @@
 
-import parsing
-import cmd
+from . import parsing
+cmd = __import__("sys").modules["pymol.cmd"]
 
 def get_command_keywords(self_cmd=cmd):
+    import pymol.diagnosing
     return {
         # keyword : [ command, # min_arg, max_arg, separator, mode ]
 
@@ -46,6 +47,7 @@ def get_command_keywords(self_cmd=cmd):
         'color'         : [ self_cmd.color             , 0 , 0 , ''  , parsing.STRICT ],
         'config_mouse'  : [ self_cmd.config_mouse      , 0 , 0 , ''  , parsing.STRICT ],
         'copy'          : [ self_cmd.copy              , 0 , 0 , ''  , parsing.LEGACY ],
+        'copy_to'       : [ self_cmd.copy_to           , 0 , 0 , ''  , parsing.STRICT ],
         'count_atoms'   : [ self_cmd.count_atoms       , 0 , 0 , ''  , parsing.STRICT ],
         'count_frames'  : [ self_cmd.count_frames      , 0 , 0 , ''  , parsing.STRICT ],   
         'count_states'  : [ self_cmd.count_states      , 0 , 0 , ''  , parsing.STRICT ],
@@ -59,6 +61,7 @@ def get_command_keywords(self_cmd=cmd):
         'deprotect'     : [ self_cmd.deprotect         , 0 , 0 , ''  , parsing.STRICT ],
         'desaturate'    : [ self_cmd.desaturate        , 0 , 0 , ''  , parsing.STRICT ],
         'deselect'      : [ self_cmd.deselect          , 0 , 0 , ''  , parsing.STRICT ],
+        'diagnostics'   : [ pymol.diagnosing.diagnostics,0 , 0 , ''  , parsing.STRICT ],
         'dihedral'      : [ self_cmd.dihedral          , 0 , 0 , ''  , parsing.STRICT ],
         'dir'           : [ self_cmd.ls                , 0 , 0 , ''  , parsing.STRICT ],
         'disable'       : [ self_cmd.disable           , 0 , 0 , ''  , parsing.STRICT ],
@@ -99,6 +102,7 @@ def get_command_keywords(self_cmd=cmd):
         'get_distance'  : [ self_cmd.get_distance      , 0 , 0 , ''  , parsing.STRICT ],
         'get_extent'    : [ self_cmd.get_extent        , 0 , 0 , ''  , parsing.STRICT ],
         'get_position'  : [ self_cmd.get_position      , 0 , 0 , ''  , parsing.STRICT ],
+        'get_sasa_relative' : [ self_cmd.get_sasa_relative , 0 , 0 , ''  , parsing.STRICT ],
         'get_symmetry'  : [ self_cmd.get_symmetry      , 0 , 0 , ''  , parsing.STRICT ],
         'get_renderer'  : [ self_cmd.get_renderer      , 0 , 0 , ''  , parsing.STRICT ],
         'get_title'     : [ self_cmd.get_title         , 0 , 0 , ''  , parsing.STRICT ],   
@@ -176,6 +180,7 @@ def get_command_keywords(self_cmd=cmd):
         'mouse'         : [ self_cmd.mouse             , 0 , 0 , ''  , parsing.STRICT ],
         'morph'         : [ self_cmd.morph             , 0 , 0 , ''  , parsing.STRICT ],
         'multisave'     : [ self_cmd.multisave         , 0 , 0 , ''  , parsing.STRICT ],
+        'multifilesave' : [ self_cmd.multifilesave     , 0 , 0 , ''  , parsing.STRICT ],
         'mview'         : [ self_cmd.mview             , 0 , 0 , ''  , parsing.STRICT ],
         'order'         : [ self_cmd.order             , 0 , 0 , ''  , parsing.STRICT ],
         'origin'        : [ self_cmd.origin            , 0 , 0 , ''  , parsing.STRICT ],
@@ -264,9 +269,11 @@ def get_command_keywords(self_cmd=cmd):
         'unpick'        : [ self_cmd.unpick            , 0 , 0 , ''  , parsing.STRICT ],
         'undo'          : [ self_cmd.undo              , 0 , 0 , ''  , parsing.STRICT ],
         'ungroup'       : [ self_cmd.ungroup           , 0 , 0 , ''  , parsing.STRICT ],
+        'uniquify'      : [ self_cmd.uniquify          , 0 , 0 , ''  , parsing.STRICT ],
         'unmask'        : [ self_cmd.unmask            , 0 , 0 , ''  , parsing.STRICT ],
         'unset'         : [ self_cmd.unset             , 0 , 0 , ''  , parsing.STRICT ],
         'unset_bond'    : [ self_cmd.unset_bond        , 0 , 0 , ''  , parsing.STRICT ],               
+        'unset_deep'    : [ self_cmd.unset_deep        , 0 , 0 , ''  , parsing.STRICT ],
         'update'        : [ self_cmd.update            , 0 , 0 , ''  , parsing.STRICT ],
         'valence'       : [ self_cmd.valence           , 0 , 0 , ''  , parsing.STRICT ],           
         'vdw_fit'       : [ self_cmd.vdw_fit           , 0 , 0 , ''  , parsing.STRICT ],   
